# yacht
*YAML conversion to HTML*

Whilst static web pages are less popular nowadays, this project aims to simplify(?) their creation by using a more human friendly markup language. 

No more searching for unterminated tags and improved readability - thanks to YAML's indented structure
## Requirements
unsurprisingly, you need the PyYAML package, to process the YAML files

## Usage:
for now you can run it as:

`python3 -m yacht.convert input.yaml > output.html`

propper support for parameters will be added soon
